@@ -7,9 +7,9 @@ use utf8;
 use parent 'BorderStyleBase';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-01-24'; # DATE
+our $DATE = '2022-01-26'; # DATE
 our $DIST = 'BorderStyleBase'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 our %BORDER = (
     v => 2,
@@ -18,13 +18,15 @@ our %BORDER = (
         # 0    1    2    3    4    5    6    7     <-- x
         ['A', 'B', 'C', 'D'],                      # 0
         ['E', 'F', 'G'],                           # 1
-        ['H', 'I', 'J', 'K', 'a', 'b'],            # 2
+        ['H', 'I', 'J', 'K', 'a', 'b', 'c', 'd'],  # 2
         ['L', 'M', 'N'],                           # 3
         ['O', 'P', 'Q', 'R', 'e', 'f', 'g', 'h'],  # 4
         ['S', 'T', 'U', 'V'],                      # 5
 
         ['Ȧ', 'Ḃ', 'Ċ', 'Ḋ'], # 6
         ['Ṣ', 'Ṭ', 'Ụ', 'Ṿ'], # 7
+
+        ['Ȯ', 'Ṗ', 'Ꝙ', 'Ṙ', 'ė', 'ḟ', 'ġ', 'ḣ'],  # 8
     ],
     utf8 => 1,
 );
@@ -44,7 +46,7 @@ BorderStyle::Test::Labeled
 
 =head1 VERSION
 
-This document describes version 0.010 of BorderStyle::Test::Labeled (from Perl distribution BorderStyleBase), released on 2022-01-24.
+This document describes version 0.011 of BorderStyle::Test::Labeled (from Perl distribution BorderStyleBase), released on 2022-01-26.
 
 =head1 HOMEPAGE
 
